==================
Examples
==================

The VKY Analytics github repository
`flounder_sharadar_examples <https://github.com/vky-analytics/flounder_sharadar_examples>`_ provides several IPython notebooks
illustrating the usage of the *fsharadar* module within
the research platform applications:

- **sep_ingest.ipynb**: shows the interface for ingesting `Sharadar Equity Prices (SEP) <https://www.quandl.com/databases/SEP/data>`_ into the Zipline data bundle. 

- **sep_get_pricing.ipynb**: demonstrates the *get_pricing* method by loading the data bundle with equity prices and adjusting them for the specified time
  interval.

- **daily_ingest.ipynb**: shows the interface for ingesting
  `Sharadar Daily Metrics of US Core Fundamentals Data <https://www.quandl.com/databases/SF1/data>`_
  into the Zipline data bundle.

- **daily_load_pipeline.ipynb**: demonstrates the interface for loading and running the Zipline
  pipeline. 

  


